Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: tools/perf/benchmarks/page_cycler_v2.py

Issue 2642723005: [not for commit] Add necessary code to enable per-request CPU benchmarking (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/fetch/ResourceFetcher.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/perf/benchmarks/page_cycler_v2.py
diff --git a/tools/perf/benchmarks/page_cycler_v2.py b/tools/perf/benchmarks/page_cycler_v2.py
index 49b5077aeb1157a6343d6eec0a4f94137d2a8ead..9ce6c7823b00aca3dc4db1ec08efad5672b12262 100644
--- a/tools/perf/benchmarks/page_cycler_v2.py
+++ b/tools/perf/benchmarks/page_cycler_v2.py
@@ -28,7 +28,8 @@ def AugmentOptionsForLoadingMetrics(tbm_options):
cat_filter.AddIncludedCategory('navigation')
cat_filter.AddIncludedCategory('blink.user_timing')
# "loading" is needed for first-meaningful-paint computation.
cat_filter.AddIncludedCategory('loading')
# "toplevel" category is used to capture TaskQueueManager events
@@ -36,6 +37,7 @@ def AugmentOptionsForLoadingMetrics(tbm_options):
cat_filter.AddIncludedCategory('toplevel')
tbm_options.AddTimelineBasedMetric('loadingMetric')
+ tbm_options.AddTimelineBasedMetric('resourceCPUMetric')
return tbm_options
« no previous file with comments | « third_party/WebKit/Source/core/fetch/ResourceFetcher.cpp ('k') | no next file » | no next file with comments »
@@ -28,7 +28,8 @@ def AugmentOptionsForLoadingMetrics(tbm_options):
cat_filter.AddIncludedCategory('navigation')
cat_filter.AddIncludedCategory('blink.user_timing')
- # "loading" is needed for first-meaningful-paint computation.
+ # "loading" is needed for first-meaningful-paint computation, and for
+ # cpu-bound resource metrics.
cat_filter.AddIncludedCategory('loading')
# "toplevel" category is used to capture TaskQueueManager events

Powered by Google App Engine
This is Rietveld 408576698